#
# spec file for package python-gql
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-gql
Version:        3.5.3
Release:        1.1
Summary:        GraphQL client for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://gql.readthedocs.io
Source:         https://github.com/graphql-python/gql/archive/refs/tags/v%{version}.tar.gz#/gql-%{version}.tar.gz
Patch0:         fix-tests.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module aiofiles}
BuildRequires:  %{python_module aiohttp}
BuildRequires:  %{python_module anyio}
BuildRequires:  %{python_module backoff >= 1.10.0}
BuildRequires:  %{python_module botocore}
BuildRequires:  %{python_module flake8-import-order}
BuildRequires:  %{python_module flake8}
BuildRequires:  %{python_module graphql-core >= 3.2 with %python-graphql-core < 3.4}
BuildRequires:  %{python_module httpx}
BuildRequires:  %{python_module parse}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pycodestyle}
BuildRequires:  %{python_module pylama}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest-vcr}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests-toolbelt}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module websockets}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module yarl}
# /SECTION
Requires:       python-anyio
Requires:       python-backoff >= 1.11.1
Requires:       python-yarl >= 1.6
Requires:       (python-graphql-core >= 3.2 with python-graphql-core < 3.4)
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
GraphQL client for Python.

%prep
%setup -q -n gql-%{version}
%autopatch -p1

# remove not needed gql-checker subproject
rm -Rf gql-checker

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/gql-cli

%check
# skip some non-functional tests
%pytest -k "not (test_aiohttp_using_cli_ep or test_cli_ep_version or test_httpx_using_cli_ep or test_async_client_validation)"

%files %{python_files}

%post
%python_install_alternative gql-cli

%postun
%python_uninstall_alternative gql-cli

%files %{python_files}
%license LICENSE
%doc README.md
%python_alternative %{_bindir}/gql-cli
%{python_sitelib}/gql
%{python_sitelib}/gql-%{version}.dist-info

%changelog
* Fri May 30 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 3.5.3
  * Bump graphql-core to v3.2.6 (#547)
- Switch build system from setuptools to pyproject.toml
  * Add python-pip and python-wheel to BuildRequires
  * Replace %%python_build with %%pyproject_wheel
  * Replace %%python_install with %%pyproject_install
  * Update name for dist directory in %%files section
- Use Python 3.11 on SLE-15 by default
* Sun Mar  9 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 3.5.2:
  * Now supporting graphql-core v3.2.4 again (See issue #534)
  - Allow graphql-core 3.2.4 by retrofitting introspection
    commits #535
- update to 3.5.1:
  Issue #529 reported that by default the AIOHTTPTransport was not
  validating ssl certificates (a self-certificate was accepted by
  default).
  This version adds a warning to warn users (See PR #533).
  As a workaround, using ssl=True in the transport arguments fix
  the issue.
  graphql-core has been restricted to <3.2.4 to fix tests.
  A new stable version will be made shortly.
* Tue Sep 24 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.5.0
- Specfile cleanup
- Use tarball from github
- Run tests
- Add patch
  * fix-tests.patch
* Tue Jan  7 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.2.0
